#include <QtGui>

#include "config.h"

Config::Config ( QWidget *parent )
	: QDialog ( parent )
{
	setupUi ( this );
	
	loadSettings();
	
	connect ( applyPushButton, SIGNAL ( clicked() ), this, SLOT ( save() ) );
	connect ( cancelPushButton, SIGNAL ( clicked() ), this, SLOT ( close() ) );
	connect ( contentsListWidget, SIGNAL ( currentItemChanged ( QListWidgetItem *, QListWidgetItem * ) ),
			this, SLOT ( changePage ( QListWidgetItem *, QListWidgetItem* ) ) );
	connect ( defaultPushButton, SIGNAL ( clicked() ), this, SLOT ( restore() ) );
	connect ( okPushButton, SIGNAL ( clicked() ), this, SLOT ( ok() ) );
}

void Config::changePage ( QListWidgetItem *current, QListWidgetItem *previous )
{
	if ( !current )
		current = previous;
	
	stackedWidget->setCurrentIndex ( contentsListWidget->row ( current ) );
}

void Config::loadSettings()
{
	QSettings settings ( "user", "QFlv2Avi" );
	QString lang = settings.value ( "lang", QString ( "en" ) ).toString();
	if ( lang == "en" )
		langComboBox->setCurrentIndex ( 0 );
	if ( lang == "fi" )
		langComboBox->setCurrentIndex ( 1 );
	if ( lang == "fr" )
		langComboBox->setCurrentIndex ( 2 );
	if ( lang == "de" )
		langComboBox->setCurrentIndex ( 3 );
	if ( lang == "it" )
		langComboBox->setCurrentIndex ( 4 );
}

void Config::restore()
{
	if ( QMessageBox::warning ( this,
								tr ( "QFlv2Avi By Burns - Warning" ),
								tr ( "All parameters will be set to default.\nContinue ?" ),
								QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No )
		return;
	
	langComboBox->setCurrentIndex ( 0 );
}

void Config::save()
{
	enum Languages { English, Finnish, French, German, Italian };
	
	QSettings settings ( "user", "QFlv2Avi" );
	QString lang;
	
	switch ( langComboBox->currentIndex() )
	{
	case English:
		lang = "en";
		break;
	case Finnish:
		lang = "fi";
		break;
	case French:
		lang = "fr";
		break;
	case German:
		lang = "de";
		break;
	case Italian:
		lang = "it";
		break;
	}
	
	if ( settings.value ( "lang", QString ( "en" ) ).toString() != lang )
	{
		settings.setValue ( "lang", lang );
		QMessageBox::information ( this,
								tr ( "QFlv2Avi By Burns" ),
	 							tr ( "You need to restart the application to change the language." ),
								QMessageBox::Ok );
	}
}
