#include "mainwindow.h"

#include <QtGui>

MainWindow::MainWindow()
    : QWidget()
{
	setupUi(this);
	
	configDialog = new Config ( this );
	
	setGeometry ( x(), y(), 320, 200 );
	
	OUTEXT = "avi";
	inExt = "flv";
	outExt = OUTEXT;
	
	flvRadioButton->setText ( flvRadioButton->text().replace ( "%out%", OUTEXT ) );
	aviRadioButton->setText ( aviRadioButton->text().replace ( "%out%", OUTEXT ) );
	
	connect ( aviRadioButton, SIGNAL ( clicked() ), this, SLOT ( setConversionType() ) );
	connect ( browse1PushButton, SIGNAL ( clicked() ), this, SLOT ( browseInputFile() ) );
	connect ( browse2PushButton, SIGNAL ( clicked() ), this, SLOT ( browseOutputFile() ) );
	connect ( cancelPushButton, SIGNAL ( clicked() ), this, SLOT ( abort() ) );
	connect ( confPushButton, SIGNAL ( clicked() ), configDialog, SLOT ( exec() ) );
	connect ( flvRadioButton, SIGNAL ( clicked() ), this, SLOT ( setConversionType() ) );
	connect ( startPushButton, SIGNAL ( clicked() ), this, SLOT ( start() ) );
}

void MainWindow::abort()
{
	process->kill();
	stackedWidget->setCurrentIndex ( 0 );
}

void MainWindow::browseInputFile()
{
	inputLineEdit->setText ( QFileDialog::getOpenFileName ( this,
																tr ( "Select the input file" ),
																QDir::homePath(),
																"*." + inExt ) );
	QString text = inputLineEdit->text();
	if ( text.mid ( text.length() - 3, 3 ) == inExt )
		outputLineEdit->setText ( text.replace ( ( text.length() - 3 ), 3, outExt ) );
	else
		outputLineEdit->setText ( text );
}

void MainWindow::browseOutputFile()
{
	outputLineEdit->setText ( QFileDialog::getSaveFileName ( this,
																tr ( "Select the output file" ),
    																QDir::homePath(),
    																"*." + outExt ) );
}

void MainWindow::encodeError()
{
	QMessageBox::critical ( this,
	 						tr ( "QFlv2Avi By Burns" ),
	 						tr ( "There was an error during ripping." ),
							QMessageBox::Ok );
	stackedWidget->setCurrentIndex ( 0 );
}

void MainWindow::finish()
{
	progressBar->setValue ( progressBar->maximum() );
	QMessageBox::information ( this,
								tr ( "QFlv2Avi By Burns" ),
								tr ( "Ripping finished !" ),
								QMessageBox::Ok );
	stackedWidget->setCurrentIndex ( 0 );
}

void MainWindow::read()
{
	QString output = process->readAllStandardOutput ();
	QString error = process->readAllStandardError ();
	QString err0;
	if ( ( output != QString::null ) && ( error == QString::null ) )
		err0 = output;
	else
		err0 = error;
	
	//label_3->setText ( err0 );
	
	if ( err0.contains ( "Duration:" ) )
	{
		QString a = err0.mid ( err0.indexOf ( "Duration:" ) + 10, 10 );
		QStringList time = a.split ( ":" );
		timeH = ( time.value ( 0 ) ).toInt();
		timeM = ( time.value ( 1 ) ).toInt();
		timeS = ( ( ( time.value ( 2 ) ).split ( "." ) ).value ( 0 ) ).toInt();
		totalTime = timeH*3600 + timeM*60 + timeS;
		progressBar->setRange ( 0, totalTime );
		//label_3->setText ( err0 );
		//setWindowTitle ( a + " " + QString::number ( totalTime ) );
	}
	
	if ( err0.contains ( "time=" ) )
	{
		QString a = err0.mid ( err0.indexOf ( "time=" ) + 5 );
		QString time = a.mid ( 0, a.indexOf ( "." ) );
		//setWindowTitle ( time + " " + QString::number ( totalTime ) );
		progressBar->setValue ( time.toInt() );
	}
	
	if ( err0.contains ( "global headers" ) )
		finish();
	if ( err0.contains ( "error" ) )
		encodeError();
}

void MainWindow::setConversionType()
{
	if ( flvRadioButton->isChecked() )
	{
		inExt = "flv";
		outExt = OUTEXT;
	} else {
		inExt = OUTEXT;
		outExt = "flv";
	}
	
	flvRadioButton->setText ( flvRadioButton->text().replace ( "%out%", OUTEXT ) );
	aviRadioButton->setText ( aviRadioButton->text().replace ( "%out%", OUTEXT ) );
}

void MainWindow::start()
{
	if ( inputLineEdit->text() == 0 || outputLineEdit->text() == 0 )
		return;
	
	QFile outputFile ( outputLineEdit->text() );
	if ( outputFile.exists() )
		if ( QMessageBox::question ( this,
									tr ( "QFlv2Avi By Burns" ),
									tr ( "The output file already exists.\nOverwrite it ?" ),
									QMessageBox::Yes, QMessageBox::No ) == 16384 )
			outputFile.remove();
		else
			return;
	
	stackedWidget->setCurrentIndex ( 1 );
	
	QString program = "ffmpeg";
	QStringList args;
	args << "-i" << inputLineEdit->text() << "-f" << outExt << outputLineEdit->text();
	
	process = new QProcess ( this );
	process->start ( program, args );
	
	//setWindowTitle ( args.join ( " " ) );
	
	connect ( process, SIGNAL ( readyReadStandardError() ), this, SLOT ( read() ) );
	connect ( process, SIGNAL ( readyReadStandardOutput() ), this, SLOT ( read() ) );
}
